@@ -15,11 +15,16 @@
 #include <fmt/ostream.h>
 #include <fmt/xchar.h>
 #include <reproc++/run.hpp>
-#ifdef _WIN32
-#include <WinReg.hpp>
 
-#include "mamba/util/os_win.hpp"
+// clang-format off
+#ifdef _WIN32
+#   include <WinReg.hpp>
+
+#   include "mamba/util/os_win.hpp"
+#else
+#   include <unistd.h>
 #endif
+// clang-format on
 
 #include "mamba/core/activation.hpp"
 #include "mamba/core/context.hpp"
